genshi.template.base.TemplateError

Package genshi :: Package template :: Module base :: Class TemplateError |

# Class TemplateError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  TemplateError

Known Subclasses:
  - loader.TemplateNotFound
  - , TemplateSyntaxError
  - , TemplateRuntimeError

Base exception class for errors related to template processing.

Instance Methods
__init__(self, message, filename=None, lineno=-1, offset=-1) Create the exception. |
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables
| msg the error message string
| filename the name of the template file
| lineno the number of the line containing the error
| offset the offset on the line

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, message, filename=None, lineno=-1, offset=-1) (Constructor) |
Create the exception. Parameters: `message` - the error message `filename` - the filename of the template `lineno` - the number of line in the template at which the error occurred `offset` - the column number at which the error occurred Overrides: object.__init__